@@ -1,14 +1,12 @@
-/* -*- Mode: C; indent-tabs-mode: t; c-basic-offset: 4; tab-width: 4 -*- */
 /*
- * callbacks.h
- * Copyright (C) Pietro Pilolli 2010 <pilolli@fbk.eu>
+ * Copyright (C) Pietro Pilolli 2010 <pilolli.pietro@gmail.com>
  * 
- * spotlighter is free software: you can redistribute it and/or modify it
+ * Spotlighter is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the
  * Free Software Foundation, either version 3 of the License, or
  * (at your option) any later version.
  * 
- * spotlighter is distributed in the hope that it will be useful, but
+ * Spotlighter is distributed in the hope that it will be useful, but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  * See the GNU General Public License for more details.
@@ -17,6 +15,21 @@
  * with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
+#include <math.h>
+#include <stdlib.h>
+
+#include <gdk/gdkkeysyms.h>
 #include <gtk/gtk.h>
 
-gboolean destroy (GtkWidget *widget, gpointer data);
+#include <cairo.h>
+
+
+#define BACKGROUND_COLOR "000000FF"
+#define SPOTLIGHTER_COLOR "0000000"
+
+
+/* Destroy the main window. */
+gboolean destroy        (GtkWidget  *widget,
+                         gpointer    data);
+
+
